package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseInspectProject;

/**
 * 巡检项目信息Mapper接口
 * 
 * @author Open Platform
 * @date 2024-01-17
 */
public interface DmsBaseInspectProjectMapper 
{
    /**
     * 查询巡检项目信息
     * 
     * @param inspectProjectId 巡检项目信息主键
     * @return 巡检项目信息
     */
    public DmsBaseInspectProject selectDmsBaseInspectProjectByInspectProjectId(Long inspectProjectId);

    /**
     * 查询巡检项目信息列表
     * 
     * @param dmsBaseInspectProject 巡检项目信息
     * @return 巡检项目信息集合
     */
    public List<DmsBaseInspectProject> selectDmsBaseInspectProjectList(DmsBaseInspectProject dmsBaseInspectProject);

    /**
     * 新增巡检项目信息
     * 
     * @param dmsBaseInspectProject 巡检项目信息
     * @return 结果
     */
    public int insertDmsBaseInspectProject(DmsBaseInspectProject dmsBaseInspectProject);

    /**
     * 修改巡检项目信息
     * 
     * @param dmsBaseInspectProject 巡检项目信息
     * @return 结果
     */
    public int updateDmsBaseInspectProject(DmsBaseInspectProject dmsBaseInspectProject);

    /**
     * 删除巡检项目信息
     * 
     * @param inspectProjectId 巡检项目信息主键
     * @return 结果
     */
    public int deleteDmsBaseInspectProjectByInspectProjectId(Long inspectProjectId);

    /**
     * 批量删除巡检项目信息
     * 
     * @param inspectProjectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseInspectProjectByInspectProjectIds(Long[] inspectProjectIds);
}
