package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseInspectProject;
import com.hw.dms.service.IDmsBaseInspectProjectService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 巡检项目信息Controller
 *
 * @author Open Platform
 * @date 2024-01-17
 */
@RestController
@RequestMapping("/dmsBaseInspectProject")
public class DmsBaseInspectProjectController extends BaseController
{
    @Autowired
    private IDmsBaseInspectProjectService dmsBaseInspectProjectService;

    /**
     * 查询巡检项目信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseInspectProject dmsBaseInspectProject)
    {
        startPage();
        List<DmsBaseInspectProject> list = dmsBaseInspectProjectService.selectDmsBaseInspectProjectList(dmsBaseInspectProject);
        return getDataTable(list);
    }

    /**
     * 导出巡检项目信息列表
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:export")
    @Log(title = "巡检项目信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseInspectProject dmsBaseInspectProject)
    {
        List<DmsBaseInspectProject> list = dmsBaseInspectProjectService.selectDmsBaseInspectProjectList(dmsBaseInspectProject);
        ExcelUtil<DmsBaseInspectProject> util = new ExcelUtil<DmsBaseInspectProject>(DmsBaseInspectProject.class);
        util.exportExcel(response, list, "巡检项目信息数据");
    }

    /**
     * 获取巡检项目信息详细信息
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:query")
    @GetMapping(value = "/{inspectProjectId}")
    public AjaxResult getInfo(@PathVariable("inspectProjectId") Long inspectProjectId)
    {
        return success(dmsBaseInspectProjectService.selectDmsBaseInspectProjectByInspectProjectId(inspectProjectId));
    }

    /**
     * 新增巡检项目信息
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:add")
    @Log(title = "巡检项目信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseInspectProject dmsBaseInspectProject)
    {
        return toAjax(dmsBaseInspectProjectService.insertDmsBaseInspectProject(dmsBaseInspectProject));
    }

    /**
     * 修改巡检项目信息
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:edit")
    @Log(title = "巡检项目信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseInspectProject dmsBaseInspectProject)
    {
        return toAjax(dmsBaseInspectProjectService.updateDmsBaseInspectProject(dmsBaseInspectProject));
    }

    /**
     * 删除巡检项目信息
     */
    @RequiresPermissions("dms:dmsBaseInspectProject:remove")
    @Log(title = "巡检项目信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{inspectProjectIds}")
    public AjaxResult remove(@PathVariable Long[] inspectProjectIds)
    {
        return toAjax(dmsBaseInspectProjectService.deleteDmsBaseInspectProjectByInspectProjectIds(inspectProjectIds));
    }
}
